//
// World.cs: Redland Initialization class
//
// $Id: Redland.cs,v 1.5 2005/01/05 11:41:42 edd Exp $
//
// Author:
//	Cesar Lopez Nataren (cesar@ciencias.unam.mx)
//  Edd Dumbill <edd@usefulinc.com>
//
// (C) 2004 Cesar Lopez Nataren
// (C) 2005 Edd Dumbill

using System;
using System.Runtime.InteropServices;

namespace Redland {

	internal class Redland {

		internal static World World = new World ();

	}
}
